@@ -15,13 +15,14 @@
  *
 */
 
-#include <ignition/common/MouseEvent.hh>
-#include <ignition/math/Color.hh>
+#include <gz/common/KeyEvent.hh>
+#include <gz/common/MouseEvent.hh>
+#include <gz/math/Color.hh>
 
-#include "ignition/gui/Conversions.hh"
+#include "gz/gui/Conversions.hh"
 
 //////////////////////////////////////////////////
-QColor ignition::gui::convert(const ignition::math::Color &_color)
+QColor gz::gui::convert(const gz::math::Color &_color)
 {
   return QColor(_color.R()*255.0,
                 _color.G()*255.0,
@@ -30,40 +31,40 @@ QColor ignition::gui::convert(const ignition::math::Color &_color)
 }
 
 //////////////////////////////////////////////////
-ignition::math::Color ignition::gui::convert(const QColor &_color)
+gz::math::Color gz::gui::convert(const QColor &_color)
 {
-  return ignition::math::Color(_color.red() / 255.0,
+  return gz::math::Color(_color.red() / 255.0,
                        _color.green() / 255.0,
                        _color.blue() / 255.0,
                        _color.alpha() / 255.0);
 }
 
 //////////////////////////////////////////////////
-QPointF ignition::gui::convert(const ignition::math::Vector2d &_pt)
+QPointF gz::gui::convert(const gz::math::Vector2d &_pt)
 {
   return QPointF(_pt.X(), _pt.Y());
 }
 
 //////////////////////////////////////////////////
-ignition::math::Vector2d ignition::gui::convert(const QPointF &_pt)
+gz::math::Vector2d gz::gui::convert(const QPointF &_pt)
 {
-  return ignition::math::Vector2d(_pt.x(), _pt.y());
+  return gz::math::Vector2d(_pt.x(), _pt.y());
 }
 
 //////////////////////////////////////////////////
-QVector3D ignition::gui::convert(const ignition::math::Vector3d &_vec)
+QVector3D gz::gui::convert(const gz::math::Vector3d &_vec)
 {
   return QVector3D(_vec.X(), _vec.Y(), _vec.Z());
 }
 
 //////////////////////////////////////////////////
-ignition::math::Vector3d ignition::gui::convert(const QVector3D &_vec)
+gz::math::Vector3d gz::gui::convert(const QVector3D &_vec)
 {
-  return ignition::math::Vector3d(_vec.x(), _vec.y(), _vec.z());
+  return gz::math::Vector3d(_vec.x(), _vec.y(), _vec.z());
 }
 
 //////////////////////////////////////////////////
-ignition::common::MouseEvent ignition::gui::convert(const QMouseEvent &_e)
+gz::common::MouseEvent gz::gui::convert(const QMouseEvent &_e)
 {
   common::MouseEvent event;
   event.SetPos(_e.pos().x(), _e.pos().y());
@@ -113,26 +114,67 @@ ignition::common::MouseEvent ignition::gui::convert(const QMouseEvent &_e)
   return event;
 }
 
-/////////////////////////////////////////////////
-ignition::common::Time ignition::gui::convert(const ignition::msgs::Time &_t)
+//////////////////////////////////////////////////
+gz::common::MouseEvent gz::gui::convert(const QWheelEvent &_e)
 {
-#ifndef _WIN32
-# pragma GCC diagnostic push
-# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-#endif
-  ignition::common::Time result(_t.sec(), _t.nsec());
-  return result;
-#ifndef _WIN32
-# pragma GCC diagnostic pop
+  common::MouseEvent event;
+
+  event.SetType(common::MouseEvent::SCROLL);
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+  event.SetPos(_e.x(), _e.y());
+#else
+  event.SetPos(_e.position().x(), _e.position().y());
 #endif
+  double scroll = (_e.angleDelta().y() > 0) ? -1.0 : 1.0;
+  event.SetScroll(scroll, scroll);
+
+  // Buttons
+  if (_e.buttons() & Qt::LeftButton)
+    event.SetButtons(event.Buttons() | common::MouseEvent::LEFT);
+
+  if (_e.buttons() & Qt::RightButton)
+    event.SetButtons(event.Buttons() | common::MouseEvent::RIGHT);
+
+  if (_e.buttons() & Qt::MiddleButton)
+    event.SetButtons(event.Buttons() | common::MouseEvent::MIDDLE);
+
+  // Modifiers
+  if (_e.modifiers() & Qt::ShiftModifier)
+    event.SetShift(true);
+
+  if (_e.modifiers() & Qt::ControlModifier)
+    event.SetControl(true);
+
+  if (_e.modifiers() & Qt::AltModifier)
+    event.SetAlt(true);
+
+  return event;
 }
 
-/////////////////////////////////////////////////
-ignition::msgs::Time ignition::gui::convert(const ignition::common::Time &_t)
+//////////////////////////////////////////////////
+gz::common::KeyEvent gz::gui::convert(const QKeyEvent &_e)
 {
-  ignition::msgs::Time result;
-  result.set_sec(_t.sec);
-  result.set_nsec(_t.nsec);
-  return result;
+  common::KeyEvent event;
+  event.SetKey(_e.key());
+  event.SetText(_e.text().toStdString());
+
+  if (_e.type() == QEvent::KeyPress)
+  {
+    event.SetType(common::KeyEvent::PRESS);
+  }
+  else if (_e.type() == QEvent::KeyRelease)
+  {
+    event.SetType(common::KeyEvent::RELEASE);
+  }
+  else
+  {
+    event.SetType(common::KeyEvent::NO_EVENT);
+  }
+
+  event.SetControl(_e.modifiers() & Qt::ControlModifier);
+  event.SetShift(_e.modifiers() & Qt::ShiftModifier);
+  event.SetAlt(_e.modifiers() & Qt::AltModifier);
+
+  return event;
 }
 
