@@ -17,14 +17,14 @@
 
 #include <gtest/gtest.h>
 
-#include <ignition/common/Console.hh>
+#include <gz/common/Console.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
 
-#include "ignition/gui/Enums.hh"
-#include "ignition/gui/DragDropModel.hh"
+#include "gz/gui/Enums.hh"
+#include "gz/gui/DragDropModel.hh"
 
-using namespace ignition;
+using namespace gz;
 using namespace gui;
 
 /////////////////////////////////////////////////
