@@ -18,15 +18,15 @@
 #include <sys/stat.h>
 #include <algorithm>
 #include <string>
-#include <ignition/math/Helpers.hh>
+#include <gz/math/Helpers.hh>
 
-#include "ignition/gui/Application.hh"
-#include "ignition/gui/Enums.hh"
-#include "ignition/gui/Helpers.hh"
-#include "ignition/gui/MainWindow.hh"
+#include "gz/gui/Application.hh"
+#include "gz/gui/Enums.hh"
+#include "gz/gui/Helpers.hh"
+#include "gz/gui/MainWindow.hh"
 
 /////////////////////////////////////////////////
-std::string ignition::gui::humanReadable(const std::string &_key)
+std::string gz::gui::humanReadable(const std::string &_key)
 {
   std::string humanKey = _key;
   humanKey[0] = toupper(humanKey[0]);
@@ -35,7 +35,7 @@ std::string ignition::gui::humanReadable(const std::string &_key)
 }
 
 /////////////////////////////////////////////////
-std::string ignition::gui::unitFromKey(const std::string &_key,
+std::string gz::gui::unitFromKey(const std::string &_key,
     const std::string &_type)
 {
   if (_key == "pos" || _key == "length" || _key == "min_depth")
@@ -110,7 +110,7 @@ std::string ignition::gui::unitFromKey(const std::string &_key,
 }
 
 /////////////////////////////////////////////////
-void ignition::gui::rangeFromKey(const std::string &_key, double &_min,
+void gz::gui::rangeFromKey(const std::string &_key, double &_min,
     double &_max)
 {
   // Maximum range by default
@@ -139,19 +139,19 @@ void ignition::gui::rangeFromKey(const std::string &_key, double &_min,
 }
 
 /////////////////////////////////////////////////
-ignition::gui::StringType ignition::gui::stringTypeFromKey(
+gz::gui::StringType gz::gui::stringTypeFromKey(
     const std::string &_key)
 {
   if (_key == "innerxml")
   {
-    return ignition::gui::StringType::PLAIN_TEXT;
+    return gz::gui::StringType::PLAIN_TEXT;
   }
 
   return StringType::LINE;
 }
 
 /////////////////////////////////////////////////
-std::string ignition::gui::uniqueFilePath(const std::string &_pathAndName,
+std::string gz::gui::uniqueFilePath(const std::string &_pathAndName,
     const std::string &_extension)
 {
   std::string result = _pathAndName + "." + _extension;
@@ -168,7 +168,7 @@ std::string ignition::gui::uniqueFilePath(const std::string &_pathAndName,
 }
 
 /////////////////////////////////////////////////
-QStringList ignition::gui::worldNames()
+QStringList gz::gui::worldNames()
 {
   auto win = App()->findChild<MainWindow *>();
   if (nullptr == win)
@@ -182,7 +182,21 @@ QStringList ignition::gui::worldNames()
 }
 
 /////////////////////////////////////////////////
-const QString ignition::gui::qmlQrcImportPath()
+std::string gz::gui::renderEngineName()
+{
+  auto win = App()->findChild<MainWindow *>();
+  if (nullptr == win)
+    return {};
+
+  auto renderEngineNameVariant = win->property("renderEngine");
+  if (!renderEngineNameVariant.isValid())
+    return {};
+
+  return renderEngineNameVariant.toString().toStdString();
+}
+
+/////////////////////////////////////////////////
+const QString gz::gui::qmlQrcImportPath()
 {
   return "qrc:/ign-gui-qml/";
 }
