@@ -18,17 +18,27 @@
 #include "MinimalScene.hh"
 
 #include <algorithm>
+#include <list>
 #include <map>
 #include <sstream>
 #include <string>
 #include <vector>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/KeyEvent.hh>
-#include <ignition/common/MouseEvent.hh>
-#include <ignition/math/Vector2.hh>
-#include <ignition/math/Vector3.hh>
-#include <ignition/plugin/Register.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/KeyEvent.hh>
+#include <gz/common/MouseEvent.hh>
+#include <gz/math/Vector2.hh>
+#include <gz/math/Vector3.hh>
+
+#ifdef _MSC_VER
+#pragma warning(push, 0)
+#endif
+#include <gz/msgs/boolean.pb.h>
+#ifdef _MSC_VER
+#pragma warning(pop)
+#endif
+
+#include <gz/plugin/Register.hh>
 
 // TODO(louise) Remove these pragmas once ign-rendering
 // is disabling the warnings
@@ -36,24 +46,26 @@
 #pragma warning(push, 0)
 #endif
 
-#include <ignition/rendering/Camera.hh>
-#include <ignition/rendering/RayQuery.hh>
-#include <ignition/rendering/RenderEngine.hh>
-#include <ignition/rendering/RenderingIface.hh>
-#include <ignition/rendering/Scene.hh>
-#include <ignition/rendering/Utils.hh>
+#include <gz/rendering/Camera.hh>
+#include <gz/rendering/RayQuery.hh>
+#include <gz/rendering/RenderEngine.hh>
+#include <gz/rendering/RenderingIface.hh>
+#include <gz/rendering/Scene.hh>
+#include <gz/rendering/Utils.hh>
 
 #ifdef _MSC_VER
 #pragma warning(pop)
 #endif
 
-#include "ignition/gui/Application.hh"
-#include "ignition/gui/Conversions.hh"
-#include "ignition/gui/GuiEvents.hh"
-#include "ignition/gui/Helpers.hh"
-#include "ignition/gui/MainWindow.hh"
+#include <gz/transport/Node.hh>
 
-Q_DECLARE_METATYPE(ignition::gui::plugins::RenderSync*)
+#include "gz/gui/Application.hh"
+#include "gz/gui/Conversions.hh"
+#include "gz/gui/GuiEvents.hh"
+#include "gz/gui/Helpers.hh"
+#include "gz/gui/MainWindow.hh"
+
+Q_DECLARE_METATYPE(gz::gui::plugins::RenderSync*)
 
 /// \brief Private data class for IgnRenderer
 class ignition::gui::plugins::IgnRenderer::Implementation
@@ -67,12 +79,23 @@ class ignition::gui::plugins::IgnRenderer::Implementation
   /// \brief Flag to indicate if drop event is dirty
   public: bool dropDirty{false};
 
-  /// \brief Mouse event
+  /// \brief Current mouse event
   public: common::MouseEvent mouseEvent;
 
+  /// \brief A list of mouse events
+  public: std::list<common::MouseEvent> mouseEvents;
+
   /// \brief Key event
   public: common::KeyEvent keyEvent;
 
+  /// \brief Max number of mouse events to store in the queue.
+  /// These events are then propagated to other gui plugins. A queue is used
+  /// instead of just keeping the latest mouse event so that we can capture
+  /// important events like mouse presses. However we keep the queue size
+  /// small on purpose so that we do not flood other gui plugins with events
+  /// that may be outdated.
+  public: const unsigned int kMaxMouseEventSize = 5u;
+
   /// \brief Mutex to protect mouse events
   public: std::mutex mutex;
 
@@ -130,7 +153,7 @@ class ignition::gui::plugins::IgnRenderer::Implementation
 ///
 ///
 /// For more info see
-/// https://github.com/ignitionrobotics/ign-rendering/issues/304
+/// https://github.com/gazebosim/gz-rendering/issues/304
 class ignition::gui::plugins::RenderSync
 {
   /// \brief Cond. variable to synchronize rendering on specific events
@@ -202,7 +225,7 @@ class ignition::gui::plugins::MinimalScene::Implementation
 {
 };
 
-using namespace ignition;
+using namespace gz;
 using namespace gui;
 using namespace plugins;
 
@@ -306,20 +329,42 @@ void IgnRenderer::Render(RenderSync *_renderSync)
   // view control
   this->HandleMouseEvent();
 
-  if (ignition::gui::App())
+  if (gz::gui::App())
   {
-    ignition::gui::App()->sendEvent(
-        ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
+    gz::gui::App()->sendEvent(
+        gz::gui::App()->findChild<gz::gui::MainWindow *>(),
         new gui::events::PreRender());
   }
 
   // update and render to texture
   this->dataPtr->camera->Update();
 
-  if (ignition::gui::App())
+  if (!this->cameraViewController.empty())
   {
-    ignition::gui::App()->sendEvent(
-        ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
+    std::string viewControlService = "/gui/camera/view_control";
+    transport::Node node;
+    std::function<void(const msgs::Boolean &, const bool)> cb =
+        [&](const msgs::Boolean &/*_rep*/, const bool _result)
+    {
+      if (!_result)
+      {
+        // LCOV_EXCL_START
+        ignerr << "Error setting view controller. Check if the View Angle GUI "
+                  "plugin is loaded." << std::endl;
+        // LCOV_EXCL_STOP
+      }
+      this->cameraViewController = "";
+    };
+
+    msgs::StringMsg req;
+    req.set_data(this->cameraViewController);
+    node.Request(viewControlService, req, cb);
+  }
+
+  if (gz::gui::App())
+  {
+    gz::gui::App()->sendEvent(
+        gz::gui::App()->findChild<gz::gui::MainWindow *>(),
         new gui::events::Render());
   }
   _renderSync->ReleaseQtThreadFromBlock(lock);
@@ -329,14 +374,21 @@ void IgnRenderer::Render(RenderSync *_renderSync)
 void IgnRenderer::HandleMouseEvent()
 {
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
+  for (const auto &e : this->dataPtr->mouseEvents)
+  {
+    this->dataPtr->mouseEvent = e;
+
+    this->BroadcastDrag();
+    this->BroadcastMousePress();
+    this->BroadcastLeftClick();
+    this->BroadcastRightClick();
+    this->BroadcastScroll();
+    this->BroadcastKeyPress();
+    this->BroadcastKeyRelease();
+  }
+  this->dataPtr->mouseEvents.clear();
+
   this->BroadcastHoverPos();
-  this->BroadcastDrag();
-  this->BroadcastMousePress();
-  this->BroadcastLeftClick();
-  this->BroadcastRightClick();
-  this->BroadcastScroll();
-  this->BroadcastKeyPress();
-  this->BroadcastKeyRelease();
   this->BroadcastDrop();
   this->dataPtr->mouseDirty = false;
 }
@@ -410,8 +462,6 @@ void IgnRenderer::BroadcastDrag()
 
   events::DragOnScene dragEvent(this->dataPtr->mouseEvent);
   App()->sendEvent(App()->findChild<MainWindow *>(), &dragEvent);
-
-  this->dataPtr->mouseDirty = false;
 }
 
 /////////////////////////////////////////////////
@@ -432,8 +482,6 @@ void IgnRenderer::BroadcastLeftClick()
 
   events::LeftClickOnScene leftClickOnSceneEvent(this->dataPtr->mouseEvent);
   App()->sendEvent(App()->findChild<MainWindow *>(), &leftClickOnSceneEvent);
-
-  this->dataPtr->mouseDirty = false;
 }
 
 /////////////////////////////////////////////////
@@ -454,8 +502,6 @@ void IgnRenderer::BroadcastRightClick()
 
   events::RightClickOnScene rightClickOnSceneEvent(this->dataPtr->mouseEvent);
   App()->sendEvent(App()->findChild<MainWindow *>(), &rightClickOnSceneEvent);
-
-  this->dataPtr->mouseDirty = false;
 }
 
 /////////////////////////////////////////////////
@@ -469,8 +515,6 @@ void IgnRenderer::BroadcastMousePress()
 
   events::MousePressOnScene event(this->dataPtr->mouseEvent);
   App()->sendEvent(App()->findChild<MainWindow *>(), &event);
-
-  this->dataPtr->mouseDirty = false;
 }
 
 /////////////////////////////////////////////////
@@ -484,8 +528,6 @@ void IgnRenderer::BroadcastScroll()
 
   events::ScrollOnScene scrollOnSceneEvent(this->dataPtr->mouseEvent);
   App()->sendEvent(App()->findChild<MainWindow *>(), &scrollOnSceneEvent);
-
-  this->dataPtr->mouseDirty = false;
 }
 
 /////////////////////////////////////////////////
@@ -528,7 +570,7 @@ std::string IgnRenderer::Initialize()
     std::map<std::string, std::string> params;
     params["useCurrentGLContext"] = "1";
     params["winID"] = std::to_string(
-        ignition::gui::App()->findChild<ignition::gui::MainWindow *>()->
+        gz::gui::App()->findChild<gz::gui::MainWindow *>()->
         QuickWindow()->winId());
     engine = rendering::engine(this->engineName, params);
   }
@@ -641,7 +683,9 @@ void IgnRenderer::NewDropEvent(const std::string &_dropText,
 void IgnRenderer::NewMouseEvent(const common::MouseEvent &_e)
 {
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
-  this->dataPtr->mouseEvent = _e;
+  if (this->dataPtr->mouseEvents.size() >= this->dataPtr->kMaxMouseEventSize)
+    this->dataPtr->mouseEvents.pop_front();
+  this->dataPtr->mouseEvents.push_back(_e);
   this->dataPtr->mouseDirty = true;
 }
 
@@ -807,7 +851,7 @@ void TextureNode::PrepareNode()
   // However we need to synchronize the threads when resolution changes,
   // and we're also currently doing everything in lockstep (i.e. both Qt
   // and worker thread are serialized,
-  // see https://github.com/ignitionrobotics/ign-rendering/issues/304 )
+  // see https://github.com/gazebosim/gz-rendering/issues/304 )
   //
   // We need to emit even if newId == 0 because it's safe as long as both
   // threads are forcefully serialized and otherwise we may get a
@@ -1003,6 +1047,14 @@ void RenderWindowItem::SetCameraHFOV(const math::Angle &_fov)
   this->dataPtr->renderThread->ignRenderer.cameraHFOV = _fov;
 }
 
+/////////////////////////////////////////////////
+void RenderWindowItem::SetCameraViewController(
+  const std::string &_view_controller)
+{
+  this->dataPtr->renderThread->ignRenderer.cameraViewController =
+    _view_controller;
+}
+
 /////////////////////////////////////////////////
 MinimalScene::MinimalScene()
   : Plugin(), dataPtr(utils::MakeUniqueImpl<Implementation>())
@@ -1142,6 +1194,12 @@ void MinimalScene::LoadConfig(const tinyxml2::XMLElement *_pluginElem)
         renderWindow->SetCameraHFOV(fov);
       }
     }
+
+    elem = _pluginElem->FirstChildElement("view_controller");
+    if (nullptr != elem && nullptr != elem->GetText())
+    {
+      renderWindow->SetCameraViewController(elem->GetText());
+    }
   }
 
   renderWindow->SetEngineName(cmdRenderEngine);
@@ -1154,14 +1212,14 @@ void MinimalScene::LoadConfig(const tinyxml2::XMLElement *_pluginElem)
 }
 
 /////////////////////////////////////////////////
-void RenderWindowItem::OnHovered(const ignition::math::Vector2i &_hoverPos)
+void RenderWindowItem::OnHovered(const gz::math::Vector2i &_hoverPos)
 {
   this->dataPtr->renderThread->ignRenderer.NewHoverEvent(_hoverPos);
 }
 
 /////////////////////////////////////////////////
 void RenderWindowItem::OnDropped(const QString &_drop,
-    const ignition::math::Vector2i &_dropPos)
+    const gz::math::Vector2i &_dropPos)
 {
   this->dataPtr->renderThread->ignRenderer.NewDropEvent(
     _drop.toStdString(), _dropPos);
@@ -1296,5 +1354,5 @@ void MinimalScene::SetLoadingError(const QString &_loadingError)
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(ignition::gui::plugins::MinimalScene,
-                    ignition::gui::Plugin)
+IGNITION_ADD_PLUGIN(gz::gui::plugins::MinimalScene,
+                    gz::gui::Plugin)
