@@ -17,12 +17,12 @@
 
 #include "ShutdownButton.hh"
 
-#include <ignition/plugin/Register.hh>
+#include <gz/plugin/Register.hh>
 
-#include "ignition/gui/Application.hh"
-#include "ignition/gui/MainWindow.hh"
+#include "gz/gui/Application.hh"
+#include "gz/gui/MainWindow.hh"
 
-using namespace ignition;
+using namespace gz;
 using namespace gui;
 using namespace plugins;
 
